hyperspy\.models package
========================

Submodules
----------

hyperspy\.models\.edsmodel module
---------------------------------

.. automodule:: hyperspy.models.edsmodel
    :members:
    :undoc-members:
    :show-inheritance:

hyperspy\.models\.edssemmodel module
------------------------------------

.. automodule:: hyperspy.models.edssemmodel
    :members:
    :undoc-members:
    :show-inheritance:

hyperspy\.models\.edstemmodel module
------------------------------------

.. automodule:: hyperspy.models.edstemmodel
    :members:
    :undoc-members:
    :show-inheritance:

hyperspy\.models\.eelsmodel module
----------------------------------

.. automodule:: hyperspy.models.eelsmodel
    :members:
    :undoc-members:
    :show-inheritance:

hyperspy\.models\.model1d module
--------------------------------

.. automodule:: hyperspy.models.model1d
    :members:
    :undoc-members:
    :show-inheritance:

hyperspy\.models\.model2d module
--------------------------------

.. automodule:: hyperspy.models.model2d
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: hyperspy.models
    :members:
    :undoc-members:
    :show-inheritance:
